package jp.gr.java_conf.coskx.multipleactivities;

import androidx.activity.result.ActivityResultLauncher;
import androidx.activity.result.contract.ActivityResultContracts;
import androidx.appcompat.app.AppCompatActivity;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private final String TAG = "COSKX : MainActivity";
    public static final String DATA_TO_SUB = "DATA_TO_SUB";  //mainからsubに値を送るときの合言葉，値ごとにユニークな合言葉が必要
    public static final String DATA_TO_MAIN = "DATA_TO_MAIN";  //subからmainに値を送るときの合言葉，値ごとにユニークな合言葉が必要

    private Intent varIntent1;
    private ActivityResultLauncher<Intent> launcher;

    private int value;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.i(TAG,"onCreate");
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        Button mButton = (Button) findViewById(R.id.ID_button_main);
        mButton.setOnClickListener(MainActivity.this);
        Button mButton2 = (Button) findViewById(R.id.ID_button_main_2);
        mButton2.setOnClickListener(MainActivity.this);

        // アクティビティ1を作る これはonCreateの段階で作っておく必要がある
        varIntent1 = new Intent(getApplication(), SubActivity.class);
        launcher= registerForActivityResult(
                new ActivityResultContracts.StartActivityForResult(),
                result -> {
                    Log.i(TAG,"result");
                    if (result.getResultCode() == Activity.RESULT_OK) {
                        assert result.getData() != null;
                        int res = result.getData().getIntExtra(MainActivity.DATA_TO_MAIN, 0);
                        Toast.makeText(MainActivity.this , "returned with "+res, Toast.LENGTH_LONG).show();
                        value = res;
                    }
                });

        value = 0;
    }

    @Override
    public void onStart() {
        Log.i(TAG,"onStart");
        super.onStart();
    }

    @Override
    public void onResume() {
        Log.i(TAG,"onResume");
        super.onResume();
        TextView mTextView = (TextView) findViewById(R.id.ID_text_main);
        mTextView.setText(""+value);
    }

    @Override
    public void onPause() {
        Log.i(TAG,"onPause");
        super.onPause();
    }

    @Override
    public void onStop() {
        Log.i(TAG,"onStop");
        super.onStop();
    }

    @Override
    public void onRestart(){
        super.onRestart();
        Log.i(TAG, "onRestart");
    }

    @Override
    public void onDestroy() {
        Log.i(TAG,"onDestroy");
        super.onDestroy();
    }

    @Override
    public void onClick(View v) {
        Log.i(TAG, "onClick");
        if (v != null) {
            if (v.getId() == R.id.ID_button_main) {
                //call
                varIntent1.putExtra(MainActivity.DATA_TO_SUB, value);
                launcher.launch(varIntent1);
            } else if (v.getId() == R.id.ID_button_main_2) {
                Intent varIntent2 = new Intent(getApplicationContext(),Sub2Activity.class);
                startActivity(varIntent2);
            }
        }
    }
}
/*
(MainActivityの起動)
MainActivity: onCreate
MainActivity: onStart
MainActivity: onResume

(MainActivityのSubActivity起動ボタンクリック)
MainActivity: onClick
MainActivity: onPause

(SubActivityの起動)
SubActivity: onCreate
SubActivity: onStart
SubActivity: onResume
MainActivity: onStop (遅れてstop)

(SubActivityの戻るボタンクリック)
SubActivity: onClick
SubActivity: onPause

(MainActivityの再起動)
MainActivity: onRestart
MainActivity: onStart
MainActivity: result
MainActivity: onResume
SubActivity: onStop (遅れてstop)
SubActivity: onDestroy (遅れてDestroy)

(MainActivityのSub2Activity起動ボタンクリック)
MainActivity: onClick
MainActivity: onPause

(Sub2Activityの起動)
Sub2Activity: onCreate
Sub2Activity: onStart
Sub2Activity: onResume
MainActivity: onStop (遅れてstop)

(Sub2Activityの戻るボタンクリック)
Sub2Activity: onClick
Sub2Activity: onPause

(MainActivityの再起動)
MainActivity: onRestart
MainActivity: onStart
MainActivity: onResume
Sub2Activity: onStop (遅れてstop)
Sub2Activity: onDestroy (遅れてDestroy)

 */